@@ -2,25 +2,36 @@ package Search::OpenSearch::Result;
 use strict;
 use warnings;
 use JSON;
-use base qw( Rose::ObjectX::CAF );
+use Plack::Util::Accessor qw(
+    build_time
+    search_time
+    doc
+    code
+    success
+    msg
+    total
+);
 use overload
     '""'     => sub { $_[0]->stringify; },
     'bool'   => sub {1},
     fallback => 1;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
-__PACKAGE__->mk_accessors(
-    qw(
-        build_time
-        search_time
-        doc
-        code
-        success
-        msg
-        total
-        )
-);
+sub new {
+    my $proto = shift;
+    my $class = ref $proto || $proto;
+
+    my $self;
+    if ( @_ == 1 && ref $_[0] eq 'HASH' ) {
+        $self = bless { %{ $_[0] } }, $class;
+    }
+    else {
+        $self = bless {@_}, $class;
+    }
+
+    $self;
+}
 
 sub stringify {
     my $self = shift;
